------------------------------
-- DROP AND CREATE TABLES

DROP TABLE MEMBER;
CREATE TABLE MEMBER (
	MEMBER_ID INT NOT NULL,
	NAME VARCHAR(30),
	JOB CHAR(8),
	AGE SMALLINT,
	SALARY DECIMAL(9,2),
	DIVISION_ID INT
);

DROP TABLE DIVISION;
CREATE TABLE DIVISION (
	DIVISION_ID INT NOT NULL,
	DIVISION_NAME VARCHAR(28),
	MANAGER_ID INT	
);

------------------------------
-- IMPORT DATA

IMPORT FROM member.csv OF DEL REPLACE INTO MEMBER ;
IMPORT FROM division.csv OF DEL REPLACE INTO DIVISION ;

------------------------------
-- ADD CONSTRAINTS/INDEXES

ALTER TABLE MEMBER ADD CONSTRAINT IDX_MEMBER_ID PRIMARY KEY (MEMBER_ID) ;
ALTER TABLE DIVISION ADD CONSTRAINT IDX_DIVISION_ID PRIMARY KEY (DIVISION_ID) ;

ALTER TABLE MEMBER ADD CONSTRAINT CHECK_JOB
	CHECK (JOB IN ('ANALYST','CLERK','DESIGNER','FIELDREP','OPERATOR','PRES','SALESREP','MANAGER'))
;

ALTER TABLE MEMBER ADD CONSTRAINT CHECK_AGE CHECK (AGE >= 0 AND AGE < 130);
ALTER TABLE MEMBER ADD CONSTRAINT CHECK_SALARY CHECK (SALARY >=0) ;

ALTER TABLE MEMBER ADD CONSTRAINT FK_MEMBER_DIVISION
	FOREIGN KEY (DIVISION_ID) REFERENCES DIVISION(DIVISION_ID) ;

CREATE INDEX IDX_JOB ON MEMBER(JOB) ;
CREATE INDEX IDX_AGE ON MEMBER(AGE) ;

------------------------------
-- REORG AND RUNSTATS

REORG TABLE MEMBER INDEX IDX_MEMBER_ID ALLOW NO ACCESS ;
REORG TABLE DIVISION INDEX IDX_DIVISION_ID ALLOW NO ACCESS ;

CALL ADMIN_CMD('RUNSTATS ON TABLE '||RTRIM(CURRENT SCHEMA)||'.MEMBER WITH DISTRIBUTION AND DETAILED INDEXES ALL') ;
CALL ADMIN_CMD('RUNSTATS ON TABLE '||RTRIM(CURRENT SCHEMA)||'.DIVISION WITH DISTRIBUTION AND DETAILED INDEXES ALL') ;
